/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ksb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "TZS", "TSh" },
            { "aed", "dilham ya Falme za Kialabu" },
            { "aoa", "kwanza ya Angola" },
            { "aud", "dola ya Austlalia" },
            { "bhd", "dinali ya Bahaleni" },
            { "bif", "falanga ya Bulundi" },
            { "bwp", "pula ya Botswana" },
            { "cad", "dola ya Kanada" },
            { "cdf", "falanga ya Kongo" },
            { "chf", "falanga ya Uswisi" },
            { "cny", "yaun lenminbi ya China" },
            { "cve", "eskudo ya Kepuvede" },
            { "djf", "falanga ya Jibuti" },
            { "dzd", "dinali ya Aljelia" },
            { "egp", "pauni ya Misli" },
            { "ern", "nakfa ya Elitlea" },
            { "etb", "bil ya Uhabeshi" },
            { "eur", "yulo" },
            { "gbp", "pauni ya Uingeeza" },
            { "ghc", "sedi ya Ghana" },
            { "gmd", "dalasi ya Gambia" },
            { "gns", "falanga ya Gine" },
            { "inr", "lupia ya India" },
            { "jpy", "salafu ya Kijapani" },
            { "kes", "shilingi ya Kenya" },
            { "kmf", "falanga ya Komolo" },
            { "lrd", "dola ya Libelia" },
            { "lsl", "loti ya Lesoto" },
            { "lyd", "dinali ya Libya" },
            { "mad", "dilham ya Moloko" },
            { "mga", "falanga ya Bukini" },
            { "mro", "ugwiya ya Molitania (1973\u20132017)" },
            { "mru", "ugwiya ya Molitania" },
            { "mur", "lupia ya Molisi" },
            { "mwk", "kwacha ya Malawi" },
            { "mzm", "metikali ya Msumbiji" },
            { "nad", "dola ya Namibia" },
            { "ngn", "naila ya Naijelia" },
            { "rwf", "falanga ya Lwanda" },
            { "sar", "liyal ya Saudia" },
            { "scr", "lupia ya Shelisheli" },
            { "sdg", "dinali ya Sudani" },
            { "sdp", "pauni ya Sudani" },
            { "shp", "pauni ya Santahelena" },
            { "sle", "leoni" },
            { "sll", "leoni (1964\u20142022)" },
            { "sos", "shilingi ya Somalia" },
            { "std", "dobla ya Sao Tome na Plincipe (1977\u20132017)" },
            { "stn", "dobla ya Sao Tome na Plincipe" },
            { "szl", "lilangeni" },
            { "tnd", "dinali ya Tunisia" },
            { "tzs", "shilingi ya Tanzania" },
            { "ugx", "shilingi ya Uganda" },
            { "usd", "dola ya Malekani" },
            { "xaf", "falanga CFA BEAC" },
            { "xof", "falanga CFA BCEAO" },
            { "zar", "landi ya Aflika Kusini" },
            { "zmk", "kwacha ya Zambia (1968\u20132012)" },
            { "zmw", "kwacha ya Zambia" },
            { "zwd", "dola ya Zimbabwe" },
        };
        return data;
    }
}
